Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(372)

Unified Diff: components/html_viewer/content_handler_impl.h

Issue 1679573002: Move shell interfaces into the shell.mojom namespace. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@delegate
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/font_service/public/cpp/font_loader.cc ('k') | components/html_viewer/content_handler_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/html_viewer/content_handler_impl.h
diff --git a/components/html_viewer/content_handler_impl.h b/components/html_viewer/content_handler_impl.h
index 7aa8996f27a9dbad085b414dd55882c9cf1449fd..f63403d15345b8435a0bb8c593fbe180a64f4e69 100644
--- a/components/html_viewer/content_handler_impl.h
+++ b/components/html_viewer/content_handler_impl.h
@@ -14,11 +14,12 @@ namespace html_viewer {
class GlobalState;
-class ContentHandlerImpl : public mojo::ContentHandler {
+class ContentHandlerImpl : public mojo::shell::mojom::ContentHandler {
public:
- ContentHandlerImpl(GlobalState* global_state,
- mojo::ApplicationImpl* app,
- mojo::InterfaceRequest<ContentHandler> request);
+ ContentHandlerImpl(
+ GlobalState* global_state,
+ mojo::ApplicationImpl* app,
+ mojo::InterfaceRequest<mojo::shell::mojom::ContentHandler> request);
~ContentHandlerImpl() override;
protected:
@@ -26,15 +27,15 @@ class ContentHandlerImpl : public mojo::ContentHandler {
mojo::ApplicationImpl* app() const { return app_; }
private:
// Overridden from ContentHandler:
void StartApplication(
- mojo::InterfaceRequest<mojo::Application> request,
+ mojo::ApplicationRequest request,
mojo::URLResponsePtr response,
const mojo::Callback<void()>& destruct_callback) override;
GlobalState* global_state_;
mojo::ApplicationImpl* app_;
- mojo::StrongBinding<mojo::ContentHandler> binding_;
+ mojo::StrongBinding<mojo::shell::mojom::ContentHandler> binding_;
scoped_ptr<mojo::AppRefCount> app_refcount_;
DISALLOW_COPY_AND_ASSIGN(ContentHandlerImpl);
« no previous file with comments | « components/font_service/public/cpp/font_loader.cc ('k') | components/html_viewer/content_handler_impl.cc » ('j') | no next file with comments »
@@ -26,15 +27,15 @@ class ContentHandlerImpl : public mojo::ContentHandler {
mojo::ApplicationImpl* app() const { return app_; }
private:
- // Overridden from ContentHandler:
+ // Overridden from shell::mojom::ContentHandler:
void StartApplication(

Powered by Google App Engine
This is Rietveld 408576698